% fi-thesis-report.sty
% LaTeX style for theses reports at FI MU
% Released to public domain.
% Feel free to contribute or add bug reports in the form of issues
% in the project's repository at https://gitlab.fi.muni.cz/xukrop/fi-thesis-report/
\ProvidesClass{fi-thesis-report}[2017/06/09 v1.2 FI thesis report template]

% Based on 'article'
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions \relax
\LoadClass{article}

% Load necessary packages
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{bera}
\RequirePackage{charter}
\RequirePackage{eulervm}
\RequirePackage[a4paper, top=30mm, bottom=35mm, left=30mm, right=30mm]{geometry}
\RequirePackage[final,kerning=true,spacing=true]{microtype}
\RequirePackage[czech]{babel}
\RequirePackage{color}
\RequirePackage{graphicx}
\RequirePackage{tabularx}
\RequirePackage{ifthen}
\RequirePackage{tikz}
\usetikzlibrary{positioning}

% Define colours
\definecolor{blue-mu}{RGB}{0,39,118}

% Define name strings and setting commands
\def\@colorProfile{}
\newcommand{\setColorProfile}[1]{\def\@colorProfile{#1}}
\def\@reportType{}
\newcommand{\setReportType}[1]{\def\@reportType{#1}}
\def\@thesisType{}
\newcommand{\setThesisType}[1]{\def\@thesisType{#1}}
\def\@thesisName{}
\newcommand{\setThesisName}[1]{\def\@thesisName{#1}}
\def\@student{}
\newcommand{\setStudent}[1]{\def\@student{#1}}
\newcommand{\setSupervisor}[1]{\def\@supervisor{#1}}
\newcommand{\setConsultant}[1]{\def\@consultant{#1}}
\newcommand{\setReader}[1]{\def\@reader{#1}}
\newcommand{\setInterReader}[1]{\def\@interReader{#1}}
\def\@signature{%
\ifthenelse{\equal{\@reportType}{inter-reader}}{\@interReader}{%
\ifthenelse{\equal{\@reportType}{reader}}{\@reader}{\@supervisor}}%
}
\newcommand{\setSignature}[1]{\def\@signature{#1}}

% Determine correct title texts
\def\@titleFirst{Posudek
\ifthenelse{\equal{\@reportType}{inter-reader}}{interního oponenta}{
\ifthenelse{\equal{\@reportType}{reader}}{oponenta}{vedoucího}}
}
\def\@titleSecond{
\ifthenelse{\equal{\@thesisType}{phd}}{disertační}{%
\ifthenelse{\equal{\@thesisType}{bc}}{bakalářské}{diplomové}%
} práce}

% Document header (logo + table with names)
\AtBeginDocument{
\begin{tikzpicture}[remember picture,overlay]
\node[] (TopLeft) at (current page.north west) {};
\node[anchor=north west](FI-logo) [below right=-3mm and 11.5mm of TopLeft] {%
\ifthenelse{\equal{\@colorProfile}{bw}}%
{\includegraphics{fi-logo-bw}}%
{\includegraphics{fi-logo-color}}%
};

\node[] (TopRight) at (current page.north east) {};
\node[below left=14.3mm and 27mm of TopRight](posudek){{\large \textsc{\@titleFirst}}};
\node[below=4.9mm of posudek.east,anchor=east]{{\large \textsc{\@titleSecond}}};
\end{tikzpicture}
\medskip

\noindent
{\def\arraystretch{1.3}\tabcolsep=10pt
\begin{tabularx}{\textwidth}{@{} l >{\it} X @{}}
Název práce: & \@thesisName \\
Autor práce: & \@student
\ifthenelse{\isundefined{\@supervisor}}{}{\\Vedoucí práce: & \@supervisor}%
\ifthenelse{\isundefined{\@consultant}}{}{\\Konzultant: & \@consultant}%
\ifthenelse{\isundefined{\@reader}}{}{\\Oponent: & \@reader}%
\ifthenelse{\isundefined{\@interReader}}{}{\\Interní oponent: & \@interReader}%
\end{tabularx}
}
\vspace{-0.5em}
\par\noindent
{%
\ifthenelse{\equal{\@colorProfile}{bw}}{}{\color{blue-mu}}%
\rule{\textwidth}{0.3mm}
}
\vspace{-0.5em}
\par\@afterindentfalse\@afterheading
}

% Document footer (date, signature)
\AtEndDocument{
\vspace{2em}
\noindent
Brno \@date \hfill \@signature
}
